## Declare the plugin

```php
    Dedi\SyliusCustomerPricingPlugin\DediSyliusCustomerPricingPlugin::class => ['all' => true],
```

## Import the plugin's configuration

```yaml
# config/packages/dedi_sylius_customer_pricing_plugin.yaml
imports:
- { resource: "@DediSyliusCustomerPricingPlugin/config/config.yaml" }
```

## Modify your ChannelPricing Repository

```php
<?php

declare(strict_types=1);

namespace App\Repository\Channel;

use Dedi\SyliusCustomerPricingPlugin\Repository\ChannelPricingRepositoryInterface as DediSyliusCustomerPricingPluginChannelRepositoryInterface;
use Dedi\SyliusCustomerPricingPlugin\Repository\Trait\ChannelPricingRepositoryTrait;
use Doctrine\ORM\QueryBuilder;
use Sylius\Bundle\ResourceBundle\Doctrine\ORM\EntityRepository;

class ChannelPricingRepository extends EntityRepository implements DediSyliusCustomerPricingPluginChannelRepositoryInterface
{
    use ChannelPricingRepositoryTrait;

    public function createListQueryBuilder(string $alias = 'o'): QueryBuilder
    {
        return $this->createQueryBuilder($alias);
    }
}
```

## Declare the new resources in your config

```yaml
# config/packages/_sylius.yaml

sylius_core:
    resources:
        channel_pricing:
            classes:
                repository: App\Repository\Channel\ChannelPricingRepository
                controller: App\Controller\ChannelPricingController

sylius_addressing:
    resources:
        address:
            classes:
                model: App\Entity\Address


sylius_customer:
    resources:
        customer:
            classes:
                model: App\Entity\Customer
                repository: Tests\Dedi\SyliusCustomerPricingPlugin\Application\src\Repository\CustomerRepository

sylius_order:
    resources:
        order:
            classes:
                model: App\Entity\Order
                repository: Tests\Dedi\SyliusCustomerPricingPlugin\Application\src\Repository\OrderRepository

sylius_product:
    resources:
        product_variant:
            classes:
                model: App\Entity\ProductVariant


```

NOTE : If you have already overriden the ChannelPricing Entity, you must delete the entity and use Sylius default one.
If you need to override the ChannelPricing Entity, please refer to the [Special case](#special-case--overriding-channelpricing-entity) section.

## Add the plugin admin routes to your config

```yaml
# config/routes/sylius_admin.yaml
sylius_admin:
    resource: "@SyliusAdminBundle/Resources/config/routing.yml"
    prefix: /admin

dedi_sylius_customer_pricing_plugin_admin:
    resource: '@DediSyliusCustomerPricingPlugin/config/admin_routing.yml'
    prefix: /admin
```

## Implement the ChannelPricingController

```php
<?php

declare(strict_types=1);

namespace App\Controller;

use Dedi\SyliusCustomerPricingPlugin\Controller\Trait\ChannelPricingControllerTrait;
use Sylius\Bundle\ResourceBundle\Controller\ResourceController;

class ChannelPricingController extends ResourceController
{
    use ChannelPricingControllerTrait;
}
```

## Make Sylius entities Organization aware

```php
<?php

declare(strict_types=1);

namespace App\Entity;

use Dedi\SyliusCustomerPricingPlugin\Entity\AddressInterface;
use Dedi\SyliusCustomerPricingPlugin\Entity\Customer\Trait\AddressOrganizationAwareTrait;
use Doctrine\ORM\Mapping as ORM;
use Sylius\Component\Core\Model\Address as BaseAddress;


/**
 * @ORM\Entity
 *
 * @ORM\Table(name="sylius_address")
 */
class Address extends BaseAddress implements AddressInterface
{
    use AddressOrganizationAwareTrait;
}
```

```php
<?php

declare(strict_types=1);

namespace App\Entity;

use Dedi\SyliusCustomerPricingPlugin\Entity\Customer\Trait\CustomerOrganizationAwareTrait;
use Dedi\SyliusCustomerPricingPlugin\Entity\CustomerInterface;
use Doctrine\ORM\Mapping as ORM;
use Sylius\Component\Core\Model\Customer as BaseCustomer;


/**
 * @ORM\Entity
 *
 * @ORM\Table(name="sylius_customer")
 */
class Customer extends BaseCustomer implements CustomerInterface
{
    use CustomerOrganizationAwareTrait;
}
```

```php
<?php

declare(strict_types=1);

namespace App\Entity;

use Dedi\SyliusCustomerPricingPlugin\Entity\Customer\Trait\OrderOrganizationAwareTrait;
use Dedi\SyliusCustomerPricingPlugin\Entity\Customer\Trait\OrganizationAwareTrait;
use Dedi\SyliusCustomerPricingPlugin\Entity\OrderInterface;
use Doctrine\ORM\Mapping as ORM;
use Sylius\Component\Core\Model\Order as BaseOrder;


/**
 * @ORM\Entity
 *
 * @ORM\Table(name="sylius_order")
 */
class Order extends BaseOrder implements OrderInterface
{
    use OrderOrganizationAwareTrait;
}
```

## Override the Customer Admin form view to add the Organization Field

```twig
# templates/bundles/SyliusAdminBundle/Customer/Form/_details.html.twig

<h4 class="ui dividing header">{{ 'sylius.ui.customer_details'|trans }}</h4>
<div class="two fields">
    {{ form_row(form.firstName) }}
    {{ form_row(form.lastName) }}
</div>
{{ form_row(form.email) }}
{{ form_row(form.group) }}

{{ form_row(form.organization, {
    'remote_url': path('dedi_sylius_customer_pricing_plugin_admin_ajax_organizations_by_name_part'),
    'load_edit_url': path('dedi_sylius_customer_pricing_plugin_admin_ajax_organization_by_id')
}) }}
```

## Override the Customer Admin show view to add the Organization info

```twig
# templates/bundles/SyliusAdminBundle/Customer/Show/Details/_primary.html.twig

<div class="content">
    <a href="{{ path('sylius_admin_customer_update', {'id': customer.id}) }}" class="header">
        {{ customer.fullName|default('sylius.ui.guest_customer'|trans) }}
    </a>
    <div class="meta">
        <span class="date">{{ 'sylius.ui.customer_since'|trans }} {{ customer.createdAt|date }}</span>
        <br />
        {% if customer.organization is not null %}
            <a href="{{ path('dedi_sylius_customer_pricing_plugin_admin_organization_show', {'id': customer.organization.id}) }}">
                <span class="group">{{ 'dedi_sylius_customer_pricing_plugin.ui.organization_membership'|trans }}: {{ customer.organization }}</span>
            </a>
            <br/>
        {% endif %}
        {% if customer.group is not null %}
            <span class="group">{{ 'sylius.ui.group_membership'|trans }}: {{ customer.group }}</span>
        {% endif %}
    </div>
</div>
```

## Make Order and Customer Repositories Organization aware

```php
<?php

declare(strict_types=1);

namespace App\Repository;

use Dedi\SyliusCustomerPricingPlugin\Repository\CustomerRepositoryInterface;
use Dedi\SyliusCustomerPricingPlugin\Repository\Trait\OrganizationAwareRepositoryTrait;
use Doctrine\ORM\QueryBuilder;
use Sylius\Bundle\CoreBundle\Doctrine\ORM\CustomerRepository as BaseCustomerRepository;

class CustomerRepository extends BaseCustomerRepository implements CustomerRepositoryInterface
{
    use OrganizationAwareRepositoryTrait;

    public function createListQueryBuilder(): QueryBuilder
    {
        return $this->createQueryBuilder('o');
    }
}
```

```php
<?php

declare(strict_types=1);

namespace App\Repository;

use Dedi\SyliusCustomerPricingPlugin\Repository\OrderRepositoryInterface;
use Dedi\SyliusCustomerPricingPlugin\Repository\Trait\OrganizationAwareRepositoryTrait;
use Sylius\Bundle\CoreBundle\Doctrine\ORM\OrderRepository as BaseOrderRepository;

class OrderRepository extends BaseOrderRepository implements OrderRepositoryInterface
{
    use OrganizationAwareRepositoryTrait;
}
```

## Make ProductVariant ChannelPricingSubject

```php
<?php

declare(strict_types=1);

namespace App\Entity;

use Dedi\SyliusCustomerPricingPlugin\Entity\ChannelPricing\Trait\ChannelPricingSubjectTrait;
use Dedi\SyliusCustomerPricingPlugin\Entity\ChannelPricing\ChannelPricingSubjectInterface;
use Doctrine\ORM\Mapping as ORM;
use Sylius\Component\Core\Model\ProductVariant as BaseProductVariant;

/**
 * @ORM\Entity()
 *
 * @ORM\Table(name="sylius_product_variant")
 *
 */
class ProductVariant extends BaseProductVariant implements ChannelPricingSubjectInterface
{
    use ChannelPricingSubjectTrait;
}
```

## Implement ChannelPricingSubjectInterface and ChannelPricingSubjectTrait on your ProductVariant

```php
<?php

declare(strict_types=1);

namespace Tests\Dedi\SyliusCustomerPricingPlugin\Application\src\Entity;

use Dedi\SyliusCustomerPricingPlugin\Entity\ChannelPricing\Trait\ChannelPricingSubjectTrait;
use Dedi\SyliusCustomerPricingPlugin\Entity\ChannelPricing\ChannelPricingSubjectInterface;
use Doctrine\ORM\Mapping as ORM;
use Sylius\Component\Core\Model\ProductVariant as BaseProductVariant;

/**
 * @ORM\Entity()
 *
 * @ORM\Table(name="sylius_product_variant")
 *
 */
class ProductVariant extends BaseProductVariant implements ChannelPricingSubjectInterface
{
    use ChannelPricingSubjectTrait;
}
```

# Special case : overriding ChannelPricing Entity
## Modify your ChannelPricing Entity

```php
<?php

declare(strict_types=1);

namespace App\Entity\Channel;

use Dedi\SyliusCustomerPricingPlugin\Entity\ChannelPricing\TypeAwareInterface
use Dedi\SyliusCustomerPricingPlugin\Entity\ChannelPricing\Trait\ChannelPriceTypeAwareTrait;
use Doctrine\ORM\Mapping as ORM;
use Sylius\Component\Core\Model\ChannelPricing as BaseChannelPricing;

/**
 * @ORM\Entity
 *
 * @ORM\Table(name="sylius_channel_pricing")
 */
class ChannelPricing extends BaseChannelPricing implements TypeAwareInterface
{
    use ChannelPriceTypeAwareTrait;
}
```

## Override CustomerChannelPricing, CustomerGroupChannelPricing and OrganizationChannelPricing models

```php
<?php

declare(strict_types=1);

namespace App\Entity;

use Dedi\SyliusCustomerPricingPlugin\Entity\ChannelPricing\Customer\CustomerChannelPricingInterface;
use Dedi\SyliusCustomerPricingPlugin\Entity\ChannelPricing\Customer\CustomerChannelPricingTrait;
use Doctrine\ORM\Mapping as ORM;
use Sylius\Component\Core\Model\CustomerInterface;

/**
 * @ORM\Entity
 *
 * @ORM\Table(name="dedi_customer_pricing_customer_channel_pricing")
 */
class CustomerChannelPricing extends ChannelPricing implements CustomerChannelPricingInterface
{
    /**
     * @ORM\ManyToOne(targetEntity="Sylius\Component\Customer\Model\CustomerInterface")
     * @ORM\JoinColumn(name="customer_id", referencedColumnName="id", nullable=false, onDelete="CASCADE")
     */
    protected ?CustomerInterface $customer = null;

    use CustomerChannelPricingTrait;
}
```

```php
<?php

declare(strict_types=1);

namespace App\Entity;

use Dedi\SyliusCustomerPricingPlugin\Entity\ChannelPricing\CustomerGroup\CustomerGroupChannelPricingInterface;
use Dedi\SyliusCustomerPricingPlugin\Entity\ChannelPricing\CustomerGroup\CustomerGroupChannelPricingTrait;
use Doctrine\ORM\Mapping as ORM;
use Sylius\Component\Customer\Model\CustomerGroupInterface;

/**
 * @ORM\Entity
 *
 * @ORM\Table(name="dedi_customer_pricing_customer_group_channel_pricing")
 */
class CustomerGroupChannelPricing extends ChannelPricing implements CustomerGroupChannelPricingInterface
{
    /**
     * @ORM\ManyToOne(targetEntity="Sylius\Component\Customer\Model\CustomerGroupInterface")
     * @ORM\JoinColumn(name="customer_group_id", referencedColumnName="id", nullable=false, onDelete="CASCADE")
     */
    protected ?CustomerGroupInterface $customerGroup = null;

    use CustomerGroupChannelPricingTrait;
}
```

```php
<?php

declare(strict_types=1);

namespace App\Entity;

use Dedi\SyliusCustomerPricingPlugin\Entity\ChannelPricing\Organization\OrganizationChannelPricingInterface;
use Dedi\SyliusCustomerPricingPlugin\Entity\ChannelPricing\Organization\OrganizationChannelPricingTrait;
use Dedi\SyliusCustomerPricingPlugin\Entity\Customer\OrganizationInterface;
use Doctrine\ORM\Mapping as ORM;

/**
 * @ORM\Entity
 *
 * @ORM\Table(name="dedi_customer_pricing_organization_channel_pricing")
 */
class OrganizationChannelPricing extends ChannelPricing implements OrganizationChannelPricingInterface
{
    /**
     * @ORM\ManyToOne(targetEntity="Dedi\SyliusCustomerPricingPlugin\Entity\Customer\OrganizationInterface")
     * @ORM\JoinColumn(name="organization_id", referencedColumnName="id", nullable=false, onDelete="CASCADE")
     */

    protected ?OrganizationInterface $organization = null;

    use OrganizationChannelPricingTrait;
}
```

## Override plugin's factories to return your new models

```php
<?php

declare(strict_types=1);

namespace App\Factory;

use App\Entity\CustomerChannelPricing;
use Dedi\SyliusCustomerPricingPlugin\Entity\ChannelPricing\Customer\CustomerChannelPricingInterface;
use Dedi\SyliusCustomerPricingPlugin\Factory\CustomerChannelPricingFactory as BaseCustomerChannelPricingFactory;

class CustomerChannelPricingFactory extends BaseCustomerChannelPricingFactory
{
    public function createNew(): CustomerChannelPricingInterface
    {
        return new CustomerChannelPricing();
    }
}
```

```php
<?php

declare(strict_types=1);

namespace App\Factory;

use App\Entity\CustomerGroupChannelPricing;
use Dedi\SyliusCustomerPricingPlugin\Entity\ChannelPricing\CustomerGroup\CustomerGroupChannelPricingInterface;
use Dedi\SyliusCustomerPricingPlugin\Factory\CustomerGroupChannelPricingFactory as BaseCustomerGroupChannelPricingFactory;

class CustomerGroupChannelPricingFactory extends BaseCustomerGroupChannelPricingFactory
{
    public function createNew(): CustomerGroupChannelPricingInterface
    {
        return new CustomerGroupChannelPricing();
    }
}
```

```php
<?php

declare(strict_types=1);

namespace App\Factory;

use App\Entity\OrganizationChannelPricing;
use Dedi\SyliusCustomerPricingPlugin\Entity\ChannelPricing\Organization\OrganizationChannelPricingInterface;
use Dedi\SyliusCustomerPricingPlugin\Factory\OrganizationChannelPricingFactory as BaseOrganizationChannelPricingFactory;

class OrganizationChannelPricingFactory extends BaseOrganizationChannelPricingFactory
{
    public function createNew(): OrganizationChannelPricingInterface
    {
        return new OrganizationChannelPricing();
    }
}
```

## Decorate the plugin's factories

```yaml
services:
    App\Factory\CustomerChannelPricingFactory:
        decorates: dedi_sylius_customer_pricing_plugin.factory.customer_channel_pricing

    App\Factory\CustomerGroupChannelPricingFactory:
        decorates: dedi_sylius_customer_pricing_plugin.factory.customer_group_channel_pricing

    App\Factory\OrganizationChannelPricingFactory:
        decorates: dedi_sylius_customer_pricing_plugin.factory.organization_channel_pricing
```

## Declare the new resources in your config

```yaml
# config/packages/_sylius.yaml

sylius_core:
    resources:
        channel_pricing:
            classes:
                model: App\Entity\Channel\ChannelPricing

dedi_sylius_customer_pricing:
    resources:
        customer_channel_pricing:
            classes:
                model: App\Entity\CustomerChannelPricing
        customer_group_channel_pricing:
            classes:
                model: App\Entity\CustomerGroupChannelPricing
        organization_channel_pricing:
            classes:
                model: App\Entity\OrganizationChannelPricing
```
